/*
 * Segment 2 (KEx),  SWE2.4 Email/Fax/SMS
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.emailfaxsms;

import java.util.Collection;
import java.util.LinkedList;
import java.util.List;

import de.bsvrz.dav.daf.main.Data;

/**
 * Versandauftrag f&uuml;r SMS Mitteilungen.
 *
 * @author BitCtrl Systems GmbH, Bachraty
 */
public class SmsVersandAuftrag implements IVersandAuftrag {

	/**
	 * ID der Applikation.
	 */
	private long applikationsID;
	/**
	 * Die Laufende Nummer des Auftrags.
	 */
	private long laufendeNummer;
	/**
	 * Liste der Empf&auml;nger.
	 */
	private final List<String> empfaenger = new LinkedList<String>();
	/**
	 * Text der Nachricht.
	 */
	private String text;

	@Override
	public long getAppID() {
		return applikationsID;
	}

	/**
	 * Gibt die Liste der Empf&auml;nger zur&uuml;ck.
	 *
	 * @return Liste der Empf&auml;nger
	 */
	public Collection<String> getEmpfaenger() {
		return empfaenger;
	}

	@Override
	public long getLaufNr() {
		return laufendeNummer;
	}

	/**
	 * Ergibt den Text der Mitteilung.
	 *
	 * @return Der Text
	 */
	public String getText() {
		return text;
	}

	@Override
	public void init(final Data data) {

		applikationsID = data.getItem("MeldungsID").getItem("ApplikationsID").asUnscaledValue().longValue();
		laufendeNummer = data.getItem("MeldungsID").getItem("LaufendeNummer").asUnscaledValue().longValue();

		for (int i = 0; i < data.getItem("Empfaenger").asTextArray().getLength(); i++) {
			final String s = data.getItem("Empfaenger").asTextArray().getTextValue(i).getText();
			if (!s.equals("")) {
				empfaenger.add(s);
			}
		}

		text = data.getItem("Text").asTextValue().getText();

	}

	@Override
	public String toString() {
		return "# SMS Auftrag # AppID: " + String.valueOf(applikationsID) + " LaufendeNr: "
				+ String.valueOf(laufendeNummer) + " Empfaenger: " + empfaenger + " Text: " + text;
	}
}
