/*
 * Segment 2 (KEx),  SWE2.4 Email/Fax/SMS
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.kex.emailfaxsms;

/**
 * Ergebnis eines Versand-Versuches.
 *
 * @author BitCtrl Systems GmbH, Bachraty
 */
public class VersandStatus {

	/**
	 * Konstante.
	 */
	public static final VersandStatus NICHT_VERSENDET = new VersandStatus("Nicht versendet", false);
	/**
	 * Konstante.
	 */
	public static final VersandStatus VERSAND_OK = new VersandStatus("Versand OK", true);
	/**
	 * Die Fehlermeldung.
	 */
	private final String fehlerMeldung;
	/**
	 * Ergebnis des Versuchs.
	 */
	private final boolean erfolg;

	/**
	 * Standard Kontstruktor.
	 *
	 * @param fehlerMeldung
	 *            Die Meldung die das Ergebnis erkl&auml;rt
	 * @param erfolg
	 *            Ergebnis des Versuches
	 */
	public VersandStatus(final String fehlerMeldung, final boolean erfolg) {
		this.erfolg = erfolg;
		this.fehlerMeldung = fehlerMeldung;
	}

	/**
	 * Erfragt das Ergebnis.
	 *
	 * @return <code>true</code>, wenn Versand erfolgreich war
	 */
	public boolean getVersandErfolg() {
		return erfolg;
	}

	/**
	 * Erfragt die Begr&uuml;ndung im Fall, dass der Versand nicht erfolgreich
	 * war.
	 *
	 * @return Beschreibung des Fehlers
	 */
	public String getVersandFehlerMeldung() {
		return fehlerMeldung;
	}

	@Override
	public String toString() {
		return "STATUS: " + erfolg + " Meldung: " + fehlerMeldung;
	}
}
